@@ -548,19 +548,22 @@ static void
 build_vertical_panel (GeditPanel *panel)
 {
 	GtkStyleContext *context;
+	GtkWidget *title_frame;
 	GtkWidget *title_hbox;
 	GtkWidget *icon_name_hbox;
 	GtkWidget *dummy_label;
 	GtkWidget *close_button;
 
-	context = gtk_widget_get_style_context (GTK_WIDGET (panel));
+	/* Create title */
+	title_frame = gtk_frame_new (NULL);
+	context = gtk_widget_get_style_context (GTK_WIDGET (title_frame));
 	gtk_style_context_add_class (context, "title");
-
-	/* Create title hbox */
-	title_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
-	gtk_box_pack_start (GTK_BOX (panel->priv->main_box), title_hbox,
+	gtk_box_pack_start (GTK_BOX (panel->priv->main_box), title_frame,
 	                             FALSE, FALSE, 0);
 
+	title_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 6);
+	gtk_container_add (GTK_CONTAINER (title_frame), title_hbox);
+
 	icon_name_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
 	gtk_box_pack_start (GTK_BOX (title_hbox),
 			    icon_name_hbox,
@@ -602,7 +605,7 @@ build_vertical_panel (GeditPanel *panel)
 			    FALSE,
 			    0);
 
-	gtk_widget_show_all (title_hbox);
+	gtk_widget_show_all (title_frame);
 
 	gtk_box_pack_start (GTK_BOX (panel->priv->main_box),
 			    panel->priv->notebook,
@@ -615,18 +618,23 @@ static void
 gedit_panel_constructed (GObject *object)
 {
 	GeditPanel *panel = GEDIT_PANEL (object);
+	GtkStyleContext *context;
 
 	/* Build the panel, now that we know the orientation
 			   (_init has been called previously) */
 
+	context = gtk_widget_get_style_context (GTK_WIDGET (panel));
+
 	build_notebook_for_panel (panel);
 	if (panel->priv->orientation == GTK_ORIENTATION_HORIZONTAL)
 	{
 		build_horizontal_panel (panel);
+		gtk_style_context_add_class (context, GTK_STYLE_CLASS_HORIZONTAL);
 	}
 	else
 	{
 		build_vertical_panel (panel);
+		gtk_style_context_add_class (context, GTK_STYLE_CLASS_VERTICAL);
 	}
 
 	g_signal_connect (panel,
