@@ -28,6 +28,7 @@
 #define WINDOW_DATA_KEY	       	"GeditFileBrowserMessagesWindowData"
 
 #define BUS_CONNECT(bus, name, data) gedit_message_bus_connect(bus, MESSAGE_OBJECT_PATH, #name, (GeditMessageCallback)  message_##name##_cb, data, NULL)
+#define BUS_DISCONNECT(bus, name, data) gedit_message_bus_disconnect_by_func(bus, MESSAGE_OBJECT_PATH, #name, (GeditMessageCallback)  message_##name##_cb, data)
 
 typedef struct
 {
@@ -43,9 +44,6 @@ typedef struct
 	guint begin_loading_id;
 	guint end_loading_id;
 
-	GList *merge_ids;
-	GtkActionGroup *merged_actions;
-
 	GeditMessageBus *bus;
 	GeditFileBrowserWidget *widget;
 	GHashTable *row_tracking;
@@ -66,8 +64,6 @@ window_data_new (GeditWindow            *window,
 		 GeditFileBrowserWidget *widget)
 {
 	WindowData *data = g_slice_new (WindowData);
-	GtkUIManager *manager;
-	GList *groups;
 
 	data->bus = gedit_window_get_message_bus (window);
 	data->widget = widget;
@@ -81,14 +77,6 @@ window_data_new (GeditWindow            *window,
 					       (GDestroyNotify)g_free,
 					       NULL);
 
-	manager = gedit_file_browser_widget_get_ui_manager (widget);
-
-	data->merge_ids = NULL;
-	data->merged_actions = gtk_action_group_new ("MessageMergedActions");
-
-	groups = gtk_ui_manager_get_action_groups (manager);
-	gtk_ui_manager_insert_action_group (manager, data->merged_actions, g_list_length (groups));
-
 	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, data);
 
 	return data;
@@ -104,21 +92,10 @@ static void
 window_data_free (GeditWindow *window)
 {
 	WindowData *data = get_window_data (window);
-	GtkUIManager *manager;
-	GList *item;
 
 	g_hash_table_destroy (data->row_tracking);
 	g_hash_table_destroy (data->filters);
 
-	manager = gedit_file_browser_widget_get_ui_manager (data->widget);
-	gtk_ui_manager_remove_action_group (manager, data->merged_actions);
-
-	for (item = data->merge_ids; item; item = item->next)
-		gtk_ui_manager_remove_ui (manager, GPOINTER_TO_INT (item->data));
-
-	g_list_free (data->merge_ids);
-	g_object_unref (data->merged_actions);
-
 	g_slice_free (WindowData, data);
 
 	g_object_set_data (G_OBJECT (window), WINDOW_DATA_KEY, NULL);
@@ -582,78 +559,6 @@ message_show_files_cb (GeditMessageBus *bus,
 	gedit_file_browser_widget_show_files (data->widget);
 }
 
-static void
-message_add_context_item_cb (GeditMessageBus *bus,
-			     GeditMessage    *message,
-			     WindowData      *data)
-{
-	GtkAction *action = NULL;
-	gchar *path = NULL;
-	gchar *name;
-	GtkUIManager *manager;
-	guint merge_id;
-
-	g_object_get (message,
-			   "action", &action,
-			   "path", &path,
-			   NULL);
-
-	if (!action || !path)
-	{
-		if (action)
-			g_object_unref (action);
-
-		g_free (path);
-		return;
-	}
-
-	gtk_action_group_add_action (data->merged_actions, action);
-	manager = gedit_file_browser_widget_get_ui_manager (data->widget);
-	name = g_strconcat (gtk_action_get_name (action), "MenuItem", NULL);
-	merge_id = gtk_ui_manager_new_merge_id (manager);
-
-	gtk_ui_manager_add_ui (manager,
-			       merge_id,
-			       path,
-			       name,
-			       gtk_action_get_name (action),
-			       GTK_UI_MANAGER_AUTO,
-			       FALSE);
-
-	if (gtk_ui_manager_get_widget (manager, path))
-	{
-		data->merge_ids = g_list_prepend (data->merge_ids, GINT_TO_POINTER (merge_id));
-		g_object_set (message, "id", merge_id, NULL);
-	}
-	else
-	{
-		g_object_set (message, "id", 0, NULL);
-	}
-
-	g_object_unref (action);
-	g_free (path);
-	g_free (name);
-}
-
-static void
-message_remove_context_item_cb (GeditMessageBus *bus,
-				GeditMessage    *message,
-				WindowData      *data)
-{
-	guint merge_id = 0;
-	GtkUIManager *manager;
-
-	g_object_get (message, "id", &merge_id, NULL);
-
-	if (merge_id == 0)
-		return;
-
-	manager = gedit_file_browser_widget_get_ui_manager (data->widget);
-
-	data->merge_ids = g_list_remove (data->merge_ids, GINT_TO_POINTER (merge_id));
-	gtk_ui_manager_remove_ui (manager, merge_id);
-}
-
 static void
 message_get_view_cb (GeditMessageBus *bus,
 		     GeditMessage    *message,
@@ -698,16 +603,6 @@ register_methods (GeditWindow            *window,
 	                            MESSAGE_OBJECT_PATH,
 	                            "remove_filter");
 
-	gedit_message_bus_register (bus,
-	                            GEDIT_TYPE_FILE_BROWSER_MESSAGE_ADD_CONTEXT_ITEM,
-	                            MESSAGE_OBJECT_PATH,
-	                            "add_context_item");
-
-	gedit_message_bus_register (bus,
-	                            GEDIT_TYPE_FILE_BROWSER_MESSAGE_ID,
-	                            MESSAGE_OBJECT_PATH,
-	                            "remove_context_item");
-
 	gedit_message_bus_register (bus,
 	                            GEDIT_TYPE_MESSAGE,
 	                            MESSAGE_OBJECT_PATH,
@@ -759,9 +654,6 @@ register_methods (GeditWindow            *window,
 	BUS_CONNECT (bus, add_filter, window);
 	BUS_CONNECT (bus, remove_filter, data);
 
-	BUS_CONNECT (bus, add_context_item, data);
-	BUS_CONNECT (bus, remove_context_item, data);
-
 	BUS_CONNECT (bus, up, data);
 	BUS_CONNECT (bus, history_back, data);
 	BUS_CONNECT (bus, history_forward, data);
@@ -1045,8 +937,30 @@ void
 gedit_file_browser_messages_unregister (GeditWindow *window)
 {
 	GeditMessageBus *bus = gedit_window_get_message_bus (window);
+	WindowData *data = get_window_data (window);
 
 	cleanup_signals (window);
+
+	BUS_DISCONNECT (bus, get_root, data);
+	BUS_DISCONNECT (bus, set_root, data);
+	BUS_DISCONNECT (bus, set_emblem, data);
+	BUS_DISCONNECT (bus, add_filter, window);
+	BUS_DISCONNECT (bus, remove_filter, data);
+
+	BUS_DISCONNECT (bus, up, data);
+	BUS_DISCONNECT (bus, history_back, data);
+	BUS_DISCONNECT (bus, history_forward, data);
+
+	BUS_DISCONNECT (bus, refresh, data);
+
+	BUS_DISCONNECT (bus, set_show_hidden, data);
+	BUS_DISCONNECT (bus, set_show_binary, data);
+
+	BUS_DISCONNECT (bus, show_bookmarks, data);
+	BUS_DISCONNECT (bus, show_files, data);
+
+	BUS_DISCONNECT (bus, get_view, data);
+
 	gedit_message_bus_unregister_all (bus, MESSAGE_OBJECT_PATH);
 
 	window_data_free (window);
